
import math

''' *********************************************************************
    canevas.py

    auteur Gabriel Girard
    date de creation: 16 janvier 2017

    Cette classe permet de creer et manipuler un ecran
    d'affichage pour le jeu du tir au canon.

 ** *********************************************************************'''
class Canevas :
    ''' -----------------------------------------------------------------
    Constructeur

    On affiche les informations initiales du jeu
    ---------------------------------------------------------------------'''
    def __init__(self) :
        print("*********************************************")
        print("*           Jeu du tir au canon             *")
        print("*-------------------------------------------*")
        print("*  Points de la cible    = 250")
        print("*  Nombre de coups tires =  0 " )
        print("*********************************************")
        

    ''' -----------------------------------------------------------------
    Auteur : Gabriel Girard
    date : janvier 2017

    Destructeur de la classe Ecran.  Il ferme la fenetre.

     ---------------------------------------------------------------------'''
    def __del__(self):
        print("*********************************************")
        print("*           Jeu du tir au canon             *")
        print("*-------------------------------------------*")
        print("*          A u    r e v o i r               *")
        print("*********************************************")

    ''' -----------------------------------------------------------------
    \author Gabriel Girard
    \date janvier 2017

    Efface le contenu du canevas
    ---------------------------------------------------------------------'''
    def effacer(self):
        self.canevas.clear(sf.Color.BLACK)


    ''' -----------------------------------------------------------------
    \author Gabriel Girard
    \date 18 septembre 2015

    \brief Cette fonction calcule la position en x du boulet

    \param[in] angleRadian : l'angle du tir
    \param[in] vitesse : la vitesse initiale du boulet
    \param[in] temps : le temps passé depuis le tir
    *********************************************************************'''
    def calculerX(self, angleRadian, vitesse, temps):
        return  vitesse * math.cos(angleRadian) * temps

    ''' -----------------------------------------------------------------
    \author Gabriel Girard
    \date 18 septembre 2015

     \brief Cette fonction calcule la position en y du boulet

    \param[in] angleRadian : l'angle du tir
    \param[in] vitesse : la vitesse initiale du boulet
    \param[in] temps : le temps passé depuis le tir
    *********************************************************************'''
    def calculerY(self, pos, angleRadian, vitesse, temps):
        return pos + (vitesse * math.sin(angleRadian) * temps) - (32.2 * temps*temps/2)


    ''' -----------------------------------------------------------------
    \author Gabriel Girard
    \date 18 septembre 2015

    \brief Cette fonction place la cible sur l'écran.  On l'appelle
            aussitôt que la distance de la cible est connue.

    \param[in] distance : la distance de la cible

    <b>Sorties:</b>
        \li (\c ecran)  La fenetre d'affichage  (\c graphique)
        \li (\c ecran)  La cible   (\c graphique)
        \li (\c ecran)  Le nombre de points courant de la cible  (\c entier)
        \li (\c ecran)  Le nombre de coups tires (0)  (\c entier)
    *********************************************************************'''
    def placeCible(self, distance):
        print("*********************************************")
        print("*      c i b l e   e n    p l a c e         *")
        print("*********************************************")

    ''' -----------------------------------------------------------------
    \author Gabriel Girard
    \date 18 septembre 2015

    \brief Cette fonction place la cible sur l'écran.  On l'appelle
            aussitôt que la distance de la cible est connue.

    \param[in] distance : la distance de la cible

    <b>Sorties:</b>
        \li (\c ecran)  Le nombre de points courant de la cible  (\c entier)

    ** *********************************************************************'''
    def afficherPoints(self, points):
        print("*********************************************")
        print("*  Points de la cible    = ", points )
        print("*********************************************")

        
    ''' -----------------------------------------------------------------
    Auteur : Gabriel Girard
    date janvier 2017

    Cette fonction affiche le nombre de coups tirés

    entree :  Nombre de coups
    Sortie: (ecran)  Le nombre de coups tires  (entier)
    ** *********************************************************************'''
    def afficherCoups(self, coups):
        print("*********************************************")
        print("*  Nombre de coups tires = ", coups)  
        print("*********************************************")


    ''' -----------------------------------------------------------------
    Auteur :  Gabriel Girard
    date janvier 2017

    Cette fonction affiche la distance parcourue par l'obus

    Entrée: distance : la distance de la cible
            vitesse : la vitesse initiale du boulet
            radian : l'angle initial du canon

    Sorties: (ecran)  La distance du tir (reel)
    ** *********************************************************************'''
    def afficherTir(self, distance, vitesse, radian):
        print("*-------------------------------------------*")
        print("*  Distance parcourue par l'obus = ", distance)
        print("*-------------------------------------------*")
        

    ''' *********************************************************************
    Auteur Gabriel Girard
    date janvier 2017

    Cette fonction place la cible sur l'écran.  On l'appelle
    aussitôt que la distance de la cible est connue.

    Entrée : distance - la cote du joueur
    Sortie : (ecran) la cote
    ** *********************************************************************'''
    def afficherCote(self, cote) :
        print("*********************************************")
        print("*  V o t r e    R e s u l t a t   f i n a l *")
        print("*-------------------------------------------*")
        print("*  =======> ", cote, " <========")
        print("*********************************************")

